@@ -1,29 +1,17 @@
-/// generate random data for testing, plus some auxilliary pretty printing functions
+use crate::here;
 
-use std::fmt;
-
-/// Sum of linear weights
+/// Sum of linear weights 1..n.
+/// Also the size of an upper or lower triangular array (including the diagonal)
 pub fn wsum(n: usize) -> f64 {
     (n * (n + 1)) as f64 / 2.
 }
 
-/// helper function for formatting error messages
-pub fn emsg(file: &'static str, line: u32, msg: &'static str) -> String {
-    format!("{}:{} rstats {}", file, line, msg)
-}
-
 /// Generates a vector of n vectors, each of length d, all filled with random numbers for testing.
 /// It needs two seeds s1 and s2. Same seeds will produce the same random sequence.  
 /// Uses local closure `rand` to generate random numbers (avoids dependencies).  
 /// Random numbers are in the open interval 0..1 with uniform distribution.  
 pub fn genvec(d: usize, n: usize, s1: u32, s2: u32) -> Vec<Vec<f64>> {
-    if n * d < 1 {
-        panic!("{}",emsg(
-            file!(),
-            line!(),
-            "genvec given zero or wrong dimensions"
-        ))
-    }
+    if n * d < 1 { panic!("{}\n\tzero or wrong dimensions",here!()) }
     // random numbers generating closure with captured seeds m_z m_w
     let mut m_z = s1 as u32;
     let mut m_w = s2 as u32;
@@ -48,13 +36,7 @@ pub fn genvec(d: usize, n: usize, s1: u32, s2: u32) -> Vec<Vec<f64>> {
 /// Uses local closure `rand` to generate random numbers (avoids dependencies).  
 /// Random numbers are in the closed interval 0..255 with uniform distribution.  
 pub fn genvecu8(d: usize, n: usize, s1: u32, s2: u32) -> Vec<Vec<u8>> {
-    if n * d < 1 {
-        panic!("{}",emsg(
-            file!(),
-            line!(),
-            "genvecu8 given zero or wrong dimensions"
-        ))
-    }
+    if n * d < 1 { panic!("{}\n\tzero or wrong dimensions",here!()) } 
     // random numbers generating closure with captured seeds m_z m_w
     let mut m_z = s1 as u32;
     let mut m_w = s2 as u32;
@@ -75,29 +57,3 @@ pub fn genvecu8(d: usize, n: usize, s1: u32, s2: u32) -> Vec<Vec<u8>> {
 }
 
 
-/// GreenIt (GI) struct facilitates printing (in green) any
-/// singular type that has Display implemented.
-pub struct GI<T: fmt::Display>(pub T);
-impl<T: fmt::Display> fmt::Display for GI<T> {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "\x1B[01;92m{}\x1B[0m", self.0.to_string())
-    }
-}
-
-/// GreenVec (GV) struct facilitates printing (in green) vectors
-/// of any end type that has Display implemented.
-pub struct GV<T: fmt::Display>(pub Vec<T>);
-impl<T: fmt::Display> fmt::Display for GV<T> {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let mut s = String::from("\x1B[01;92m[");
-        let n = self.0.len();
-        if n > 0 {
-            s.push_str(&self.0[0].to_string()); // first item
-            for i in 1..n {
-                s.push_str(", ");
-                s.push_str(&self.0[i].to_string());
-            }
-        }
-        write!(f, "{}]\x1B[0m", s)
-    }
-}
